@@ -3,7 +3,7 @@ from .audio_utils import *
 from .seo_utils import *
 from .ocr_utils import *
 from .functions import *
-from .audio_utils_clean import transcribe_audio_file_clean,transcribe_with_whisper_local
+from .audio_utils import transcribe_audio_file_clean,transcribe_with_whisper_local
 # Clear root logger handlers to prevent duplicate console output
 logging.getLogger('').handlers.clear()
 
@@ -110,13 +110,13 @@ def transcribe_video_path(video_path,
                                             json_data=info,
                                             audio_path=info['audio_path'],
                                             model_size= "small",           # one of "tiny", "base", "small", "medium", "large"
-                                            language='english'
-                                            )
-    info = analyze_video_text(video_path=info['video_path'],
-                       output_dir=info['thumbnails_directory'],
-                       json_data=info,
-                       remove_phrases=info['remove_phrases'],
-                              video_id=info['video_id'])
+                                            language='english')
+    if info.get('video_text') == None:                                      
+        info = analyze_video_text(video_path=info['video_path'],
+                           output_dir=info['thumbnails_directory'],
+                           json_data=info,
+                           remove_phrases=info['remove_phrases'],
+                           video_id=info['video_id'])
     if info.get("combined_keywords") == None:
         info = get_text_and_keywords(info,
                                      summarizer=summarizer,
